"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.initCommand = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../core/utils/loggin");
const rc_json_1 = require("../../core/rc-json");
const index_1 = require("../setup/index");
const rc_1 = require("../../core/options/rc");
const options_1 = require("./options");
exports.initCommand = {
    command: 'init',
    description: 'Setup .user-flowrc.json',
    builder: (y) => y.options(options_1.INIT_OPTIONS),
    module: {
        handler: (argv) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
            (0, loggin_1.logVerbose)(`run "init" as a yargs command`);
            const cfg = yield run(argv);
            (0, loggin_1.log)('user-flow CLI is set up now! 🎉');
            (0, loggin_1.logVerbose)(cfg);
        })
    }
};
function getCLIConfigFromArgv(argv) {
    const { url, ufPath, serveCommand, awaitServeStdout, outPath, format, budgetPath, budgets } = (argv || {});
    const cfg = {
        collect: {
            url,
            ufPath,
            serveCommand,
            awaitServeStdout
        },
        persist: {
            outPath,
            format
        }
    };
    if (budgetPath || budgets) {
        cfg.assert = {
            budgetPath,
            budgets
        };
    }
    return cfg;
}
function run(argv) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const cliCfg = getCLIConfigFromArgv(argv);
        //console.log('run init', cliCfg)
        const config = Object.assign(Object.assign({}, cliCfg), (yield (0, index_1.ensureUrl)(cliCfg)
            .then(index_1.ensureUfPath)
            .then(index_1.ensureFormat)
            .then(index_1.ensureOutPath)
        // defaults should be last as it takes user settings
        ));
        const rcPath = (0, rc_1.get)();
        (0, rc_json_1.updateRcConfig)(config, rcPath);
        return config;
    });
}
exports.run = run;
//# sourceMappingURL=index.js.map