"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCliOptionsFromRcConfig = exports.updateRcConfig = exports.readRcConfig = void 0;
const file_1 = require("../utils/file");
const loggin_1 = require("../utils/loggin");
const rc_1 = require("../options/rc");
function readRcConfig(cfgPath = '') {
    const configPath = cfgPath || (0, rc_1.get)();
    const repoConfigFile = (0, file_1.readFile)(configPath) || '{}';
    (0, loggin_1.logVerbose)('readRcConfig:', configPath, JSON.parse(repoConfigFile));
    return JSON.parse(repoConfigFile);
}
exports.readRcConfig = readRcConfig;
function updateRcConfig(config, cfgPath = '') {
    const configPath = cfgPath || (0, rc_1.get)();
    (0, loggin_1.logVerbose)(`Update config under ${configPath}`);
    // NOTICE: this is needed for better git flow.
    // Touch a file only if needed
    if (JSON.stringify(readRcConfig()) !== JSON.stringify(config)) {
        (0, file_1.writeFile)(configPath, JSON.stringify(config));
        (0, loggin_1.logVerbose)(`New config ${JSON.stringify(config)}`);
    }
    else {
        (0, loggin_1.logVerbose)(`No updates for ${configPath} to save.`);
    }
}
exports.updateRcConfig = updateRcConfig;
function getCliOptionsFromRcConfig(config) {
    const { collect, persist, assert } = config;
    return Object.assign(Object.assign(Object.assign({}, collect), persist), assert);
}
exports.getCliOptionsFromRcConfig = getCliOptionsFromRcConfig;
//# sourceMappingURL=index.js.map